netapp_ontap.models.security_association_ike API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.security_association_ike`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SecurityAssociationIkeSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SecurityAssociationIke object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `authentication GET POST PATCH`

    Authentication method for internet key exchange protocol.

    Valid choices:

    - none
    - psk
    - cert
  `initiator_security_parameter_index GET POST PATCH`

    Initiator's security parameter index for the IKE security association.

  `is_initiator GET POST PATCH`

    Indicates whether or not IKE has been initiated by this node.

  `responder_security_parameter_index GET POST PATCH`

    Responder's security parameter index for the IKE security association.

  `state GET POST PATCH`

    State of the IKE connection.

    Valid choices:

    - none
    - connecting
    - established
    - dead_peer_probe
  `version GET POST PATCH`

    Internet key exchange protocol version.